@@ -27,6 +27,16 @@ class UserCreate(task_manager.Task):
         return client.keystone_client.users.create(**self.args)
 
 
+class UserDelete(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.delete(**self.args)
+
+
+class UserUpdate(task_manager.Task):
+    def main(self, client):
+        return client.keystone_client.users.update(**self.args)
+
+
 class FlavorList(task_manager.Task):
     def main(self, client):
         return client.nova_client.flavors.list()
@@ -152,6 +162,11 @@ class ImageUpdate(task_manager.Task):
         client.glance_client.images.update(**self.args)
 
 
+class ImageUpload(task_manager.Task):
+    def main(self, client):
+        client.glance_client.images.upload(**self.args)
+
+
 class VolumeCreate(task_manager.Task):
     def main(self, client):
         return client.cinder_client.volumes.create(**self.args)
@@ -159,7 +174,7 @@ class VolumeCreate(task_manager.Task):
 
 class VolumeDelete(task_manager.Task):
     def main(self, client):
-        return client.cinder_client.volumes.delete(**self.args)
+        client.cinder_client.volumes.delete(**self.args)
 
 
 class VolumeList(task_manager.Task):
@@ -203,6 +218,11 @@ class FloatingIPAttach(task_manager.Task):
         return client.nova_client.servers.add_floating_ip(**self.args)
 
 
+class FloatingIPPoolList(task_manager.Task):
+    def main(self, client):
+        return client.nova_client.floating_ip_pools.list()
+
+
 class ContainerGet(task_manager.Task):
     def main(self, client):
         return client.swift_client.head_container(**self.args)
@@ -236,3 +256,63 @@ class ObjectUpdate(task_manager.Task):
 class ObjectMetadata(task_manager.Task):
     def main(self, client):
         return client.swift_client.head_object(**self.args)
+
+
+class SubnetCreate(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.create_subnet(**self.args)
+
+
+class SubnetList(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.list_subnets()
+
+
+class SubnetDelete(task_manager.Task):
+    def main(self, client):
+        client.neutron_client.delete_subnet(**self.args)
+
+
+class SubnetUpdate(task_manager.Task):
+    def main(self, client):
+        return client.neutron_client.update_subnet(**self.args)
+
+
+class MachineCreate(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.create(**self.args)
+
+
+class MachineDelete(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.delete(**self.args)
+
+
+class MachinePatch(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.update(**self.args)
+
+
+class MachinePortCreate(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.port.create(**self.args)
+
+
+class MachinePortDelete(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.port.delete(**self.args)
+
+
+class MachineSetMaintenance(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.set_maintenance(**self.args)
+
+
+class MachineSetPower(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.set_power_state(**self.args)
+
+
+class MachineSetProvision(task_manager.Task):
+    def main(self, client):
+        return client.ironic_client.node.set_provision_state(**self.args)
